@@ -14,3 +14,10 @@ tic <- Sys.time()
 ou2.sim <- simulate(ou2,params=p,nsim=100)
 toc <- Sys.time()
 print(toc-tic)
+
+coef(ou2,c('x1.0','x2.0')) <- c(-50,50)
+
+ou2.sim <- simulate(ou2)[[1]]
+x <- simulate(ou2,nsim=3,states=T)
+y <- simulate(ou2,nsim=3,obs=T)
+z <- simulate(ou2,nsim=3,obs=T,states=T)
